# Generated by Django 5.1.2 on 2024-10-21 21:52

import django.core.validators
import django.db.models.deletion
import main.models
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='User',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('password', models.CharField(max_length=128, verbose_name='password')),
                ('last_login', models.DateTimeField(blank=True, null=True, verbose_name='last login')),
                ('email', models.EmailField(max_length=50, unique=True)),
                ('name', models.CharField(max_length=30)),
                ('birthdate', models.DateField()),
                ('avatar', models.ImageField(blank=True, default='images/user/avatars/default.jpeg', upload_to='images/user/avatars/%Y/%m/%d/', validators=[django.core.validators.FileExtensionValidator(allowed_extensions=['jpg', 'png', 'jpeg'])], verbose_name='Аватар пользователя')),
            ],
            options={
                'abstract': False,
            },
            managers=[
                ('objects', main.models.UserManager()),
            ],
        ),
        migrations.CreateModel(
            name='Author',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, unique=True, verbose_name='ФИО')),
                ('avatar', models.ImageField(blank=True, default='images/author/avatars/default.jpeg', upload_to='images/author/avatars/%Y/%m/%d/', validators=[django.core.validators.FileExtensionValidator(allowed_extensions=['jpg', 'png', 'jpeg'])], verbose_name='Аватар автора')),
            ],
            options={
                'verbose_name': 'Автор',
                'verbose_name_plural': 'Авторы',
            },
        ),
        migrations.CreateModel(
            name='Collection',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=100, unique=True, verbose_name='Название')),
            ],
            options={
                'verbose_name': 'Коллекция',
                'verbose_name_plural': 'Коллекции',
            },
        ),
        migrations.CreateModel(
            name='Genders',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=15, unique=True, verbose_name='Название')),
            ],
            options={
                'verbose_name': 'Пол',
                'verbose_name_plural': 'Полы',
            },
        ),
        migrations.CreateModel(
            name='Genre',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=50, verbose_name='Название')),
            ],
            options={
                'verbose_name': 'Жанр',
                'verbose_name_plural': 'Жанры',
            },
        ),
        migrations.CreateModel(
            name='Action',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=50, unique=True, verbose_name='Название')),
                ('weight', models.FloatField(null=True, verbose_name='Вес')),
                ('users', models.ManyToManyField(to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'Действие',
                'verbose_name_plural': 'Действия',
            },
        ),
        migrations.CreateModel(
            name='Book',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=50, unique=True, verbose_name='Название')),
                ('annotation', models.TextField(verbose_name='Аннотация')),
                ('symbols_count', models.IntegerField(null=True, verbose_name='Количество символов')),
                ('book_file', models.FileField(null=True, upload_to='books/covers/', validators=[django.core.validators.FileExtensionValidator(allowed_extensions=['epub', 'fb2', 'pdf', 'docx'])], verbose_name='Файл книги')),
                ('pages_count', models.IntegerField(null=True, verbose_name='Количество страниц')),
                ('is_recognized', models.BooleanField(default=False, verbose_name='Распознана')),
                ('last_update', models.DateTimeField(auto_now=True, verbose_name='Последнее обновление')),
                ('cover', models.FileField(blank=True, upload_to='images/covers/', validators=[django.core.validators.FileExtensionValidator(allowed_extensions=['jpg', 'png', 'jpeg'])], verbose_name='Обложка книги')),
                ('is_private', models.BooleanField(default=False, verbose_name='Личная')),
                ('authors', models.ManyToManyField(to='main.author')),
                ('genres', models.ManyToManyField(to='main.genre')),
            ],
            options={
                'verbose_name': 'Книга',
                'verbose_name_plural': 'Книги',
            },
        ),
        migrations.CreateModel(
            name='Metric',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('date', models.DateTimeField(auto_now_add=True, verbose_name='Дата')),
                ('pages_read', models.IntegerField(null=True, verbose_name='Страниц прочитано')),
                ('reading_time', models.TimeField(null=True, verbose_name='Время чтения')),
                ('books_read', models.IntegerField(null=True, verbose_name='Книг прочитано')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'Метрика',
                'verbose_name_plural': 'Метрики',
            },
        ),
        migrations.CreateModel(
            name='UsersBooksCollections',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('current_page', models.IntegerField(default=0, verbose_name='Текущая страница')),
                ('date_added', models.DateTimeField(auto_now=True, verbose_name='Дата добавления')),
                ('book', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='main.book')),
                ('collection', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='main.collection')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'ПользовательКнигаКоллекция',
                'verbose_name_plural': 'ПользователиКнигиКоллекции',
            },
        ),
    ]
