"""
URL configuration for neurea project.

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/5.1/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.contrib import admin
from django.urls import path, include
from rest_framework_simplejwt.views import TokenObtainPairView, TokenRefreshView, TokenVerifyView
from django.conf.urls.static import static
from django.conf import settings
from rest_framework import routers

from main.views import CustomRegisterView, GenreViewSet, AuthorViewSet, CollectionViewSet, GendersViewSet, ActionViewSet, MetricViewSet, UsersBooksCollectionsViewSet, BookViewSet, UserViewSet


router = routers.SimpleRouter()
router.register(r'genre', GenreViewSet, basename=['genre'])
router.register(r'author', AuthorViewSet, basename=['author'])
router.register(r'collection', CollectionViewSet, basename=['collection'])
router.register(r'genders', GendersViewSet, basename=['genders'])
router.register(r'action', ActionViewSet, basename=['action'])
router.register(r'metric', MetricViewSet, basename=['metric'])
router.register(r'book', BookViewSet, basename=['book'])
router.register(r'user', UserViewSet , basename=['user'])
router.register(r'usersbookscollections', UsersBooksCollectionsViewSet, basename=['usersbookscollections'])


urlpatterns = [
    path('admin/', admin.site.urls),
    path('api/v1/token/', TokenObtainPairView.as_view(), name='token_obtain_pair'),
    path('api/v1/token/refresh/', TokenRefreshView.as_view(), name='token_refresh'),
    path('api/v1/token/verify/', TokenVerifyView.as_view(), name='token_verify'),
    path('api/v1/auth/', include('rest_auth.urls')),
    path('api/reg/', CustomRegisterView.as_view()),
    path('api/v1/', include(router.urls))
] + static(settings.STATIC_URL, document_root=settings.STATIC_ROOT)

if settings.DEBUG:
    urlpatterns += static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)
