package com.example.neurea.views.screens

import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.PaddingValues
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.HorizontalDivider
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Switch
import androidx.compose.material3.SwitchDefaults
import androidx.compose.material3.Text
import androidx.compose.material3.TextButton
import androidx.compose.material3.TextField
import androidx.compose.material3.TextFieldDefaults
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.text.input.PasswordVisualTransformation
import androidx.compose.ui.text.input.VisualTransformation
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.example.neurea.R
import com.example.neurea.views.ui.theme.NeureaTheme

@Preview()
@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun SettingsScreen() { // navController: NavController


    NeureaTheme {
        Column(
            modifier = Modifier
                .fillMaxSize()
                .background(color = MaterialTheme.colorScheme.surface)
        ) {
            Text("Настройки приложения", color = MaterialTheme.colorScheme.primary, fontWeight = FontWeight.Bold, fontSize = 20.sp,
                modifier = Modifier
                    .align(Alignment.CenterHorizontally)
                    .padding(vertical = 80.dp))
            Column(
                modifier = Modifier
                    .clip(RoundedCornerShape(45.dp, 45.dp))
                    .background(color = MaterialTheme.colorScheme.secondary)
            ){
                Column(modifier = Modifier
                    .padding(start = 40.dp, end = 40.dp, top = 25.dp)
                    .clip(shape = RoundedCornerShape(22.dp))
                    .border(
                        width = 2.dp,
                        color = MaterialTheme.colorScheme.onSecondary,
                        shape = RoundedCornerShape(24.dp)
                    )
                    .padding(15.dp),){
                    Row(horizontalArrangement = Arrangement.SpaceAround, verticalAlignment = Alignment.CenterVertically){
                        Column(modifier = Modifier
                            .padding(0.dp, 0.dp, 5.dp, 0.dp)
                            .clip(RoundedCornerShape(6.dp))
                        ){
                            Column(modifier = Modifier
                                .background(MaterialTheme.colorScheme.primary)
                                .width(30.dp)
                                .height(30.dp)
                                , horizontalAlignment = Alignment.CenterHorizontally, verticalArrangement = Arrangement.Center
                                , ) {
                                Icon(painter = painterResource(id = R.drawable.baseline_visibility_24), "", tint = MaterialTheme.colorScheme.secondary, modifier = Modifier

                                    .height(25.dp)
                                    .width(25.dp)
                                )
                            }
                        }

                        Column(modifier = Modifier.width(190.dp)){
                            Text("Темная тема", fontWeight = FontWeight.Medium, fontSize = 14.sp)
                            Text("Сделать интерфейс приложения темным", fontWeight = FontWeight.Light, fontSize = 12.sp)
                        }
                        Column(){
                            var checked by remember { mutableStateOf(false) }
                            Switch(
                                checked = checked,
                                onCheckedChange = { checked = it },
                                modifier = Modifier.padding(10.dp),
                                colors = SwitchDefaults.colors(
                                    checkedThumbColor = MaterialTheme.colorScheme.secondary,
                                    checkedTrackColor = MaterialTheme.colorScheme.primary,
                                    uncheckedThumbColor = MaterialTheme.colorScheme.secondary,
                                    uncheckedTrackColor = MaterialTheme.colorScheme.onSecondary,
                                    uncheckedBorderColor = Color.Transparent
                                    
                                )
                            )
                        }

                    }
                        HorizontalDivider(color=MaterialTheme.colorScheme.onSecondary, thickness = 0.5.dp, modifier = Modifier.padding(start = 6.dp, end=6.dp, top = 8.dp, bottom = 17.dp))


                    Row(horizontalArrangement = Arrangement.SpaceAround, verticalAlignment = Alignment.CenterVertically){
                        Column(Modifier.width(245.dp)){
                            Text("Выйти из приложения", fontWeight = FontWeight.Medium, fontSize = 14.sp)
                            Text("По нажатию кнопки вы покинете аккаунт", fontWeight = FontWeight.Light, fontSize = 14.sp)
                        }
                        Column(modifier = Modifier
                            .padding(0.dp, 0.dp, 5.dp, 0.dp)
                            .clip(RoundedCornerShape(6.dp))
                        ){
                            Column(modifier = Modifier
                                .background(MaterialTheme.colorScheme.primary)
                                .width(30.dp)
                                .height(30.dp)
                                , horizontalAlignment = Alignment.CenterHorizontally, verticalArrangement = Arrangement.Center
                                , ) {
                                Icon(painter = painterResource(id = R.drawable.baseline_visibility_24), "", tint = MaterialTheme.colorScheme.secondary, modifier = Modifier

                                    .height(25.dp)
                                    .width(25.dp)
                                )
                            }
                        }
                    }
                    HorizontalDivider(color=MaterialTheme.colorScheme.onSecondary, thickness = 0.5.dp, modifier = Modifier.padding(start = 6.dp, end=6.dp, top = 8.dp, bottom = 17.dp))


                    Row(horizontalArrangement = Arrangement.SpaceAround, verticalAlignment = Alignment.CenterVertically){
                        Column(Modifier.width(245.dp)){
                            Text("Удалить аккаунт", fontWeight = FontWeight.Medium, fontSize = 14.sp)
                            Text("По нажатию кнопки вы удалите аккаунт", fontWeight = FontWeight.Light, fontSize = 14.sp)
                        }
                        Column(modifier = Modifier
                            .padding(0.dp, 0.dp, 5.dp, 0.dp)
                            .clip(RoundedCornerShape(6.dp))
                        ){
                            Column(modifier = Modifier
                                .background(Color(0xFFF15C5C))
                                .width(30.dp)
                                .height(30.dp),
                                horizontalAlignment = Alignment.CenterHorizontally, verticalArrangement = Arrangement.Center
                                , ) {
                                IconButton(onClick = { /*TODO*/ }) {
                                    Icon(painter = painterResource(id = R.drawable.baseline_visibility_24), "", tint = MaterialTheme.colorScheme.secondary, modifier = Modifier

                                        .height(25.dp)
                                        .width(25.dp)
                                    )
                                }
                            }
                        }
                    }


                }



            }



        }
    }
}